@@ -6,7 +6,7 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: bpcalendar.py 3415 2006-06-26 21:28:16Z djpham $
+### $Id: bpcalendar.py 3622 2006-10-20 21:43:39Z djpham $
 
 """Calendar user interface and data for bitpim.
 
@@ -748,6 +748,9 @@ class CalendarEntry(object):
         return self._data['end'].date_str()+' '+\
                self._data['end'].time_str(False, '00:00')
     end_str=property(fget=_get_end_str)
+    def open_ended(self):
+        # True if this is an open-ended event
+        return self.end[:3]==self.no_end_date
 
     def _get_vibrate(self):
         return self._data.get('vibrate', 0)
@@ -1073,10 +1076,15 @@ class Calendar(calendarcontrol.Calendar):
         as required by the parent L{calendarcontrol.Calendar} for
         display in a cell"""
         entry_list=self.getentrydata(year, month, day)
-        res=[ (i.start[3], i.start[4], i.description) \
-              for i in entry_list if not i.allday ]
-        res += [ (None, None, i.description) \
-                 for i in entry_list if i.allday ]
+        res=[]
+        for _entry in entry_list:
+            (_y,_m,_d,_h,_min, _desc)=_entry.start+(_entry.description,)
+            if _entry.allday:
+                res.append((None, None, _desc))
+            elif _entry.repeat or (_y,_m,_d)==(year, month, day):
+                res.append((_h, _min, _desc))
+            else:
+                res.append((None, None, '...'+_desc))
         res.sort()
         return res
 
@@ -1139,6 +1147,15 @@ class Calendar(calendarcontrol.Calendar):
         self._publish_today_events()
         self._publish_thisweek_events()
 
+    def _add_entries(self, entry):
+        # Add this entry, which may span several days, to the entries list
+        _t0=datetime.datetime(*entry.start[:3])
+        _t1=datetime.datetime(*entry.end[:3])
+        _oneday=datetime.timedelta(days=1)
+        for _ in range((_t1-_t0).days+1):
+            self.entries.setdefault((_t0.year, _t0.month, _t0.day), []).append(entry)
+            _t0+=_oneday
+
     def populate(self, dict):
         """Updates the internal data with the contents of C{dict['calendar']}"""
         if dict.get('calendar_version', None)==2:
@@ -1155,7 +1172,7 @@ class Calendar(calendarcontrol.Calendar):
             entry=self._data[entry]
             y,m,d,h,min=entry.start
             if entry.repeat is None:
-                self.entries.setdefault((y,m,d), []).append(entry)
+                self._add_entries(entry)
             else:
                 self.repeating.append(entry)
         # tell everyone that i've changed
@@ -1733,7 +1750,7 @@ class MergeDataTable(gridlib.PyGridTableBase):
             elif _row[self._new_index]:
                 # add this new entry
                 _key=_row[self._key_index]
-                self._old[_key]=self._new[key]
+                self._old[_key]=self._new[_key]
             elif _row[self._changed_index]:
                 # replace the old entry with this new one
                 _new_key=_row[self._key_index]
