@@ -5,7 +5,7 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: common.py 3092 2006-04-13 03:13:47Z skyjunky $
+### $Id: common.py 3532 2006-08-26 22:44:28Z djpham $
 
 
 # Documentation
@@ -539,6 +539,12 @@ def basename(name):
         name=name[pos+1:]
     return name
 
+def dirname(name):
+    if name.rfind('\\')>=0 or name.rfind('/')>=0:
+        pos=max(name.rfind('\\'), name.rfind('/'))
+        name=name[:pos]
+    return name
+
 def stripext(name):
     if name.rfind('.')>=0:
         name=name[:name.rfind('.')]
