@@ -5,7 +5,7 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: gui.py 3380 2006-06-19 07:04:34Z djpham $
+### $Id: gui.py 3628 2006-10-25 20:11:31Z djpham $
 
 """The main gui code for BitPim"""
 
@@ -317,7 +317,12 @@ class Config(ConfigParser.ConfigParser):
             self._path, self._filename=self._getdefaults()
         # read in the config if exist
         if self._filename:
-            self.read([self._filename])
+            try:
+                self.read([self._filename])
+            except:
+                # something is wrong with the config file, just bail
+                if __debug__:
+                    raise
             self.Write('path', self._path)
             self.Write('config', self._filename)
 
@@ -538,12 +543,15 @@ class MainApp(wx.App):
     def displayhelpid(self, id):
         if guihelper.IsMSWindows():
             import win32help
-            fname=guihelper.gethelpfilename()+".chm"
+            fname=guihelper.gethelpfilename()+".chm>Help"
             if id is None:
                 id=helpids.ID_WELCOME
-            # unfortunately I can't get the stupid help viewer to also make the treeview
-            # on the left to go to the right place
-            win32help.HtmlHelp(self.frame.GetHandle(), fname, win32help.HH_DISPLAY_TOPIC, id)
+            # display the topic
+            win32help.HtmlHelp(self.frame.GetHandle(), fname,
+                               win32help.HH_DISPLAY_TOPIC, id)
+            # and sync the TOC
+            win32help.HtmlHelp(self.frame.GetHandle(), fname,
+                               win32help.HH_SYNC, id)
             return
         elif guihelper.IsMac():
             if self.helpcontroller is None:
@@ -625,6 +633,13 @@ class MainApp(wx.App):
         # treading._MainThread
         sys.excepthook=donothingexceptionhandler
 
+    def ExitMainLoop(self):
+        if guihelper.IsGtk():
+            # This hangs for GTK, so what the heck!
+            self.OnExit()
+            sys.exit(0)
+        super(MainApp, self).ExitMainLoop()
+
 # do nothing exception handler
 def donothingexceptionhandler(*args):
     pass
@@ -710,8 +725,17 @@ class MainWindow(wx.Frame):
         # imports
         impmenu=wx.Menu()
         for x, desc, help, func in importexport.GetPhonebookImports():
-            impmenu.Append(x, desc, help)
-            wx.EVT_MENU(self, x, MenuCallback(func, self) )
+            if isinstance(func, tuple):
+                # submenu
+                _submenu=wx.Menu()
+                for _id, _desc, _help, _func in func:
+                    _submenu.Append(_id, _desc, _help)
+                    if _func:
+                        wx.EVT_MENU(self, _id, MenuCallback(_func, self))
+                impmenu.AppendMenu(x, desc, _submenu, help)
+            else:
+                impmenu.Append(x, desc, help)
+                wx.EVT_MENU(self, x, MenuCallback(func, self) )
 
         menu.AppendMenu(guihelper.ID_FILEIMPORT, "Import", impmenu)
 
@@ -755,11 +779,6 @@ class MainWindow(wx.Frame):
         menu.Append(guihelper.ID_DATAHISTORICAL, "&Historical Data ...", "View Current & Historical Data")
         menuBar.Append(menu, "&Data")
 
-        menu=wx.Menu()
-        menu.Append(guihelper.ID_AUTOSYNCSETTINGS, "&Configure AutoSync Settings...", "Configures Schedule Auto-Synchronisation")
-        menu.Append(guihelper.ID_AUTOSYNCEXECUTE, "&Synchronize Schedule Now", "Synchronize Schedule Now")
-        menuBar.Append(menu, "&AutoSync")
-
         menu=wx.Menu()
         menu.Append(guihelper.ID_VIEWCOLUMNS, "&Columns ...", "Which columns to show")
         menu.AppendCheckItem(guihelper.ID_VIEWPREVIEW, "&Phonebook Preview", "Toggle Phonebook Preview Pane")
@@ -881,7 +900,9 @@ class MainWindow(wx.Frame):
         self.configdlg.updatevariables()
         
         pos=self.config.ReadInt("mainwindowsplitterpos", 200)
+        self.tree.active_panel.OnPreActivate()
         self.sw.SplitVertically(self.tree, self.tree.active_panel, pos)
+        self.tree.active_panel.OnPostActivate()
         self.sw.SetMinimumPaneSize(50)
         wx.EVT_SPLITTER_SASH_POS_CHANGED(self, id, self.OnSplitterPosChanged)
         self.tree.Expand(self.tree.root)
@@ -947,6 +968,10 @@ class MainWindow(wx.Frame):
             # the app is started minimized !!
             wx.CallAfter(self.Show, False)
         self.GetStatusBar().set_app_status_ready()
+        # Linux USB port notification
+        if guihelper.IsGtk():
+            import comm_notify
+            comm_notify.start_server(self)
 
     def OnSplitterPosChanged(self,_):
         pos=self.sw.GetSashPosition()
@@ -954,12 +979,14 @@ class MainWindow(wx.Frame):
 
     def SetActivePanel(self, panel):
         w2=self.sw.GetWindow2()
-        if w2==None: # still in startup
+        if w2 is None or w2 is panel:
             return
+        panel.OnPreActivate()
         w2.Show(False)
         self.sw.ReplaceWindow(w2, panel)
         panel.Show(True)
         panel.SetFocus()
+        panel.OnPostActivate()
 
     def GetActiveMemoWidget(self):
         return self.tree.GetActivePhone().memowidget
@@ -1237,25 +1264,13 @@ class MainWindow(wx.Frame):
             if check_auto_sync:
                 # see if we should re-sync the calender on connect, do it silently
                 self.__autosync_phone(silent=1)
-        
-    def WindowsOnDeviceChanged(self, type, name="", drives=[], flag=None):
-        if not name.lower().startswith("com"):
-            return
-        if type=='DBT_DEVICEREMOVECOMPLETE':
-            print "Device remove", name
-            # device is removed, if it's ours, clear the port
-            if name.lower()==self.config.Read('lgvx4400port', '').lower():
-                if self.wt:
-                    self.wt.clearcomm()
-                self.SetPhoneModelStatus(guiwidgets.SB_Phone_Unavailable)
-            return
-        if type!='DBT_DEVICEARRIVAL':
-            # not interested
-            return
+
+    def AddComm(self, name):
+        # A new comm port became available
         print 'New device on port:',name
         # check the new device
         check_auto_sync=auto_sync.UpdateOnConnect(self)
-        if name.lower()==self.config.Read('lgvx4400port', '').lower():
+        if name and name.lower()==self.config.Read('lgvx4400port', '').lower():
             _func=self._detect_this_phone
             _args=(check_auto_sync, self._autodetect_delay, True)
         else:
@@ -1267,6 +1282,39 @@ class MainWindow(wx.Frame):
         else:
             _func(*_args)
 
+    def RemoveComm(self, name):
+        # This comm just went away
+        print "Device remove", name
+        # device is removed, if it's ours, clear the port
+        if name and name.lower()==self.config.Read('lgvx4400port', '').lower():
+            if self.wt:
+                self.wt.clearcomm()
+            self.SetPhoneModelStatus(guiwidgets.SB_Phone_Unavailable)
+
+    def NotifyComm(self, evt):
+        if evt.type==evt.add:
+            self.AddComm(evt.comm)
+        else:
+            self.RemoveComm(evt.comm)
+
+    def OnCommNotification(self, evt):
+        print 'OnCommNotification'
+        if wx.Thread_IsMain():
+            self.NotifyComm(evt)
+        else:
+            wx.CallAfter(self.NotifyComm, evt)
+
+    def WindowsOnDeviceChanged(self, type, name="", drives=[], flag=None):
+        if not name.lower().startswith("com"):
+            return
+        if type=='DBT_DEVICEREMOVECOMPLETE':
+            self.RemoveComm(name)
+            return
+        if type!='DBT_DEVICEARRIVAL':
+            # not interested
+            return
+        self.AddComm(name)
+
     def MyWndProc(self, hwnd, msg, wparam, lparam):
 
         if msg==win32con.WM_DEVICECHANGE:
