@@ -5,7 +5,7 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: outlook_calendar.py 2770 2006-01-26 05:56:51Z skyjunky $
+### $Id: outlook_calendar.py 3677 2006-11-14 03:26:11Z djpham $
 
 "Deals with Outlook calendar import stuff"
 
@@ -66,6 +66,30 @@ def set_recurrence(item, dict, oc):
     # get the recurrence pattern and map it to BP Calendar
     return oc.process_repeat(item, dict)
 
+#-------------------------------------------------------------------------------
+class ImportDataSource(common_calendar.ImportDataSource):
+    # how to define, and retrieve calendar import data source
+
+    def browse(self, parent=None):
+        # how to select a source
+        self._source=native.outlook.pickfolder()
+    
+    def name(self):
+        # return a string name for the source
+        if self._source:
+            return native.outlook.getfoldername(self._source)
+        return ''
+
+    def _get_id(self):
+        if self._source:
+            return native.outlook.getfolderid(self._source)
+        return None
+    def _set_id(self, id):
+        self._source=None
+        if id:
+            self._source=native.outlook.getfolderfromid(id, False, 'calendar')
+    id=property(fget=_get_id, fset=_set_id)
+
 #-------------------------------------------------------------------------------
 class OutlookCalendarImportData:
     _non_auto_sync_calendar_keys=[
@@ -136,7 +160,7 @@ class OutlookCalendarImportData:
     olImportanceLow  = native.outlook.outlook_com.constants.olImportanceLow
     olImportanceNormal = native.outlook.outlook_com.constants.olImportanceNormal
 
-    def __init__(self, outlook, auto_sync_only=0):
+    def __init__(self, outlook=native.outlook, auto_sync_only=0):
         self._outlook=outlook
         self._data=[]
         self._error_list=[]
@@ -343,7 +367,7 @@ class OutlookCalendarImportData:
 
     def get_folder_name(self):
         if self._folder is None:
-            return '<None>'
+            return ''
         return self._outlook.getfoldername(self._folder)
 
     def read(self, folder=None, update_dlg=None):
