@@ -7,12 +7,13 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: package.py 3435 2006-06-28 05:31:45Z rogerb $
+### $Id: package.py 3594 2006-10-03 02:44:50Z djpham $
 
 # This file provides the packaging definitions used by the buildrelease system
 
 import sys
 import os
+import os.path
 import shutil
 
 import version
@@ -29,8 +30,8 @@ def sanitycheck():
 
     print "wxPython version",
     import wx
-    if wx.VERSION[:4]!=(2,6,3,2):
-        raise Exception("Should be wxPython 2.6.3.2.  This is "+`wx.VERSION`)
+    if wx.VERSION[:4]!=(2,6,3,3):
+        raise Exception("Should be wxPython 2.6.3.3.  This is "+`wx.VERSION`)
     print "  OK"
 
     print "wxPython is unicode build",
@@ -169,14 +170,16 @@ def getversion():
     return version.version
 
 import phones
-import encodings.aliases
+import encodings
+import glob
 def getallencodingsmodules():
     # work-around for cx_freeze: add all encodings modules
-    _mod={}
-    for _key,_entry in encodings.aliases.aliases.items():
-        _mod[_entry]=None
     _res=[]
-    for _key in _mod.keys():
+    _dir=os.path.dirname(encodings.__file__)
+    _glob_name=os.path.join(_dir, '*.py')
+    _modules=[os.path.basename(os.path.splitext(x)[0]) for x in glob.glob(_glob_name) \
+              if os.path.basename(x) != '__init__.py']
+    for _key in _modules:
         # collect what we have
         try:
             _mod_name='encodings.'+_key
