@@ -5,7 +5,7 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: com_brew.py 3407 2006-06-23 04:26:20Z skyjunky $
+### $Id: com_brew.py 3593 2006-10-03 02:44:11Z djpham $
 
 """Implements the "Brew" filesystem protocol"""
 
@@ -257,10 +257,10 @@ class DebugBrewProtocol:
             results[_name]={ 'name': _name, 'type': 'file', 'size': _stat[6],
                              'date': (_date, _timestr) }
         for d in _dir:
-            results[d]={ 'name': d, 'type': 'directory' }
+            _name=dir+'/'+d
+            results[_name]={ 'name': _name, 'type': 'directory' }
             if recurse>0:
-                results.update(self.getfilesystem(os.path.join(dir, d),
-                                                  recurse-1))
+                results.update(self.getfilesystem(_name, recurse-1))
         return results
 
     def statfile(self, name):
@@ -316,7 +316,8 @@ class RealBrewProtocol:
     _brewepochtounix=315964800
 
     def __init__(self):
-        pass
+        # reset default encoding
+        p_brew.PHONE_ENCODING=p_brew.DEFAULT_PHONE_ENCODING
 
     def getfirmwareinformation(self):
         self.log("Getting firmware information")
@@ -786,6 +787,12 @@ class RealBrewProtocol:
         # the vx8300 returns yet another error for access denied (probably related to the new brew protocol)
         if ord(data[0])==0x4b and ord(data[1])==0x04 and ord(data[2])==0x1c:
             raise BrewAccessDeniedException()
+        # the lx550 returns yet another error for access denied listing directories (probably related to the new brew protocol)
+        if ord(data[0])==0x4b and ord(data[1])==0x0a and ord(data[2])==0x1c:
+            raise BrewAccessDeniedException()
+        # the lx550 returns yet another error for access denied listing files in a dir (probably related to the new brew protocol)
+        if ord(data[0])==0x4b and ord(data[1])==0x0b and ord(data[2])==0x1c:
+            raise BrewAccessDeniedException()
 
         # parse data
         buffer=prototypes.buffer(data)
@@ -1042,6 +1049,7 @@ class BrewProtocol(RealBrewProtocol):
     RealBrewProtocol and DebugBrewProtocol classes.
     """
     def __init__(self):
+        RealBrewProtocol.__init__(self)
         # if the env var PHONE_FS is set, we're debugging!
         phone_path=os.environ.get('PHONE_FS', None)
         if __debug__ and phone_path:
