@@ -1,11 +1,12 @@
 ### BITPIM
 ###
-### Copyright (C) 2003-2004 Roger Binns <rogerb@rogerbinns.com>
+### Copyright (C) 2003-2006 Roger Binns <rogerb@rogerbinns.com>
+### Copyright (C) 2006 Michael Cohen <mikepublic@nc.rr.com>
 ###
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: com_lg.py 3414 2006-06-26 21:27:27Z djpham $
+### $Id: com_lg.py 3530 2006-08-22 05:51:20Z djpham $
 
 """Phonebook conversations with LG phones"""
 
@@ -1222,12 +1223,18 @@ class LGUncountedIndexedMedia:
         media={}
 
         # builtins
+        index = 0;                      # MIC Initialize counter here, instead of the next stanza
         for i,n in enumerate(builtins): # nb zero based index whereas previous phones used 1
             media[i]={'name': n, 'origin': 'builtin'}
+            index+=1;
 
         # maps
-        index=0
-        for type, indexfile, directory, external_dir, maxentries, typemajor  in maps:
+        # index=0                       # MIC Do not want to reset index; builtins start at 0
+                                        # Otherwise, the builtins are overwriten by
+                                        # these
+        for type, indexfile, directory, external_dir, maxentries, typemajor,_idx  in maps:
+            if _idx is not None:
+                index=_idx
             for item in self.getindex(indexfile):
                 media[index]={
                     'name': basename(item.filename),
@@ -1262,7 +1269,7 @@ class LGUncountedIndexedMedia:
         # signal that we are using the new media storage that includes the origin and timestamp
         origins['new_media_version']=1
 
-        for type, indexfile, directory, external_dir, maxentries, typemajor  in maps:
+        for type, indexfile, directory, external_dir, maxentries, typemajor, _idx  in maps:
             media={}
             for item in self.getindex(indexfile):
                 data=None
@@ -1335,7 +1342,7 @@ class LGUncountedIndexedMedia:
         use_external_media=self.external_storage_present()
         skip_origin=[]
         
-        for type, indexfile, directory, external_dir, maxentries, typemajor  in maps:
+        for type, indexfile, directory, external_dir, maxentries, typemajor, _idx  in maps:
             # if no external media is present skip indexes which refer
             # to external media
             if self.is_external_media(directory) and not use_external_media:
@@ -1351,7 +1358,7 @@ class LGUncountedIndexedMedia:
 
         # build up list into init
         init={}
-        for type, indexfile, directory, external_dir, maxentries, typemajor  in maps:
+        for type, indexfile, directory, external_dir, maxentries, typemajor, _idx  in maps:
             init[type]={}
             for k in wpi.keys():
                 if wpi[k]['origin']==type:
@@ -1387,7 +1394,7 @@ class LGUncountedIndexedMedia:
                 del wp[w]
 
         # if external media is specified, add all the extra files to the index
-        for type, indexfile, directory, external_dir, maxentries, typemajor  in maps:
+        for type, indexfile, directory, external_dir, maxentries, typemajor, _idx  in maps:
             if type not in skip_origin and len(external_dir):
                 if self.is_external_media(external_dir) and not use_external_media:
                     continue
@@ -1402,7 +1409,7 @@ class LGUncountedIndexedMedia:
 
         # time to write the files out
         dircache=self.DirCache(self)
-        for type, indexfile, directory, external_dir, maxentries, typemajor  in maps:
+        for type, indexfile, directory, external_dir, maxentries, typemajor, _idx  in maps:
             if type not in skip_origin:
                 # get the old index file so we can work out what to delete
                 for item in self.getindex(indexfile):
