@@ -1,12 +1,13 @@
 ### BITPIM
 ###
-### Copyright (C) 2003-2005 Roger Binns <rogerb@rogerbinns.com>
-### Copyright (C) 2005 Simon Capper <skyjunky@sbcglobal.net>
+### Copyright (C) 2003-2006 Roger Binns <rogerb@rogerbinns.com>
+### Copyright (C) 2006-2006 Simon Capper <skyjunky@sbcglobal.net>
+### Copyright (C) 2006 Michael Cohen <mikepublic@nc.rr.com>
 ###
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: com_lgvx8100.py 3360 2006-06-12 23:16:56Z djpham $
+### $Id: com_lgvx8100.py 3584 2006-09-29 03:55:29Z djpham $
 
 """Communicate with the LG VX8100 cell phone
 
@@ -72,7 +73,7 @@ class Phone(com_lg.LGNewIndexedMedia2,com_lgvx7000.Phone):
         ( 'images', 'dload/image.dat', 'dload/imagesize.dat', 'brew/16452/mp', 100, 50, 0, 0, 0),
         ( 'video', 'dload/video.dat', None, 'brew/16452/mf', 1000, 50, 0x0304, 0, 0),
         )
-        
+
     # for removable media (miniSD cards)
     _rs_path='mmc1/'
     _rs_ringers_path=_rs_path+'ringers'
@@ -119,7 +120,7 @@ class Phone(com_lg.LGNewIndexedMedia2,com_lgvx7000.Phone):
              'sizefile': 'dload/videosize.dat',
              'dunno': 0, 'date': True },
          }
-        
+
     def __init__(self, logtarget, commport):
         com_lgvx4400.Phone.__init__(self, logtarget, commport)
         self.mode=self.MODENONE
@@ -206,7 +207,7 @@ class Phone(com_lg.LGNewIndexedMedia2,com_lgvx7000.Phone):
             t=time.strptime(memo_dict[k].date, '%b %d, %Y %H:%M')
             entry.memotime=(t.tm_year, t.tm_mon, t.tm_mday, t.tm_hour, t.tm_min)
             if 'GPStime' in entry.getfields():
-                entry.GPStime = (t.tm_year, t.tm_mon, t.tm_mday, t.tm_hour, t.tm_min, t.tm_sec)    
+                entry.GPStime = (t.tm_year, t.tm_mon, t.tm_mday, t.tm_hour, t.tm_min, t.tm_sec)
             text_memo.items.append(entry)
         buf=prototypes.buffer()
         text_memo.writetobuffer(buf, logtitle="Updated memo "+self.memolocation)
@@ -241,12 +242,20 @@ class Phone(com_lg.LGNewIndexedMedia2,com_lgvx7000.Phone):
                 # the vx8100 has a bad entry when the calender is empty
                 # stop processing the calender when we hit this record
                 if event.pos==0: #invalid entry
-                    continue                   
+                    continue
                 entry=bpcalendar.CalendarEntry()
                 entry.desc_loc=event.description
                 try: # delete events are still in the calender file but have garbage dates
                     entry.start=event.start
-                    entry.end=event.end
+                    if self.protocolclass.CALENDAR_HAS_SEPARATE_END_TIME_AND_DATE:
+                        if event.repeat[0] == 0:           # MIC:  If non-repeating event
+                            entry.end = event.end_time     # MIC:  Set entry.end to full end_time
+                        else:
+                            _,_,_,hour,minute=event.end_time
+                            year,month,day,_,_=event.end_date
+                            entry.end=(year,month,day,hour,minute)
+                    else:
+                        entry.end=event.end
                 except ValueError:
                     continue
                 if event.alarmindex_vibrate&0x1:
@@ -260,7 +269,27 @@ class Phone(com_lg.LGNewIndexedMedia2,com_lgvx7000.Phone):
                     entry.alarm=None # no alarm set
                 else:
                     entry.alarm=hour*60+min
-                entry.ringtone=result['ringtone-index'][event.ringtone]['name']
+                if self.protocolclass.CALENDAR_HAS_SEPARATE_END_TIME_AND_DATE:
+                    # MIC Unlike previous phones, the VX8300 passes the ringtone
+                    # via both the index, and a path.  If the index is set to 100
+                    # (0x64), then the ringtone information will be found in the
+                    # "ringpath", the last 256 bytes of the calendar packet.  If
+                    # the index is between 0 and 15, inclusive, then it is using
+                    # one of the builtin ringers, and the ringpath is set to
+                    # null.
+                    try:
+                        if (event.ringtone == 100):   # MIC Ringer is downloaded to phone or microSD
+                            entry.ringtone = common.basename(event.ringpath)
+                        else:                         # MIC Ringer is built-in
+                            entry.ringtone=self.builtinringtones[event.ringtone]
+                    except:
+                        # hack, not having a phone makes it hard to figure out the best approach
+                        if entry.alarm==None:
+                            entry.ringtone='No Ring'
+                        else:
+                            entry.ringtone='Loud Beeps'
+                else:
+                    entry.ringtone=result['ringtone-index'][event.ringtone]['name']
                 entry.snoozedelay=0
                 # check for exceptions and remove them
                 if event.repeat[3] and exceptions.has_key(event.pos):
@@ -313,13 +342,13 @@ class Phone(com_lg.LGNewIndexedMedia2,com_lgvx7000.Phone):
         # what are we working with
         cal=dict['calendar']
         newcal={}
-        #sort into start order, makes it possible to see if the calendar has changed        
+        #sort into start order, makes it possible to see if the calendar has changed
         keys=[(x.start, k) for k,x in cal.items()]
         keys.sort()
         # number of entries
         eventsf.numactiveitems=len(keys)
         pos=1
-        contains_alarms=False        
+        contains_alarms=False
         # play with each entry
         for (_,k) in keys:
             # entry is what we will return to user
@@ -328,7 +357,16 @@ class Phone(com_lg.LGNewIndexedMedia2,com_lgvx7000.Phone):
             data.pos=eventsf.packetsize()
             data.description=entry.desc_loc
             data.start=entry.start
-            data.end=entry.end
+            if self.protocolclass.CALENDAR_HAS_SEPARATE_END_TIME_AND_DATE:
+                year_e,month_e,day_e,hour_e,minute_e=entry.end
+                year_s,month_s,day_s,hour_s,minute_s=entry.start
+                if entry.repeat!=None:           # MIC:  Added check for repeating event
+                    data.end_date = (year_e,month_e,day_e,31,63)
+                else:
+                    data.end_date = (year_s+5,month_s,day_s,31,63)
+                data.end_time = (year_s,month_s,day_s,hour_e,minute_e)
+            else:
+                data.end=entry.end
             alarm_set=self.setalarm(entry, data)
             data.ringtone=0
             if alarm_set:
@@ -338,14 +376,38 @@ class Phone(com_lg.LGNewIndexedMedia2,com_lgvx7000.Phone):
                     alarm_name=entry.ringtone
             else:# set alarm to "No Ring" gets rid of alarm icon on phone
                 alarm_name="No Ring"
-            for i in dict['ringtone-index']:
-                if dict['ringtone-index'][i]['name']==alarm_name:
-                    data.ringtone=i
+            if self.protocolclass.CALENDAR_HAS_SEPARATE_END_TIME_AND_DATE:
+                # MIC VX8300 handles the ringtone differently than previous
+                # phones.  Except for the 16 builtin ringers, ringers stored
+                # directly on the phone or on the microSD are specified by
+                # their fully qualified path, and an index of 100.
+                for i in dict['ringtone-index']:
+                    if dict['ringtone-index'][i]['name']==alarm_name:
+                        if dict['ringtone-index'][i].get('filename', None):
+                            data.ringtone=100
+                            data.ringpath=dict['ringtone-index'][i]['filename']
+                        else:
+                            # builtin ringer
+                            data.ringtone=i      # Set to proper index
+                        break
+            else:
+                data.unknown2=0        # MIC Only unknown in VX8100 and prior
+                                       # Moved up from line below, as we do not
+                                       # want it defined for the VX8300+
+                for i in dict['ringtone-index']:
+                    if dict['ringtone-index'][i]['name']==alarm_name:
+                        data.ringtone=i
+                        break
             # check for exceptions and add them to the exceptions list
             exceptions=0
             if entry.repeat!=None:
-                if data.end[:3]==entry.no_end_date:
-                    data.end=(2100, 12, 31)+data.end[3:]
+                if self.protocolclass.CALENDAR_HAS_SEPARATE_END_TIME_AND_DATE:
+                    if data.end_date[:3]==entry.no_end_date:
+                        year_s,month_s,day_s,hour_s,minute_s=entry.start
+                        data.end_date=(year_s + 5, month_s, day_s, 31, 63)
+                else:
+                    if data.end[:3]==entry.no_end_date:
+                        data.end=(2100, 12, 31)+data.end[3:]
                 for i in entry.repeat.suppressed:
                     de=self.protocolclass.scheduleexception()
                     de.pos=data.pos
@@ -359,7 +421,9 @@ class Phone(com_lg.LGNewIndexedMedia2,com_lgvx7000.Phone):
             else:
                 data.repeat=((0,0,0,0,0))
             data.unknown1=0
-            data.unknown2=0
+            # data.unknown2=0          # MIC Moved up, since this should not be
+                                       # assigned for the VX8300; not part of the
+                                       # defined packet.
             if data.alarmindex_vibrate!=1: # if alarm set
                 contains_alarms=True
             # put entry in nice shiny new dict we are building
@@ -539,7 +603,7 @@ class Phone(com_lg.LGNewIndexedMedia2,com_lgvx7000.Phone):
             if _file not in _remote_files:
                 # remote file no longer exists, del the marker
                 self.rmfile(local_dir+'/'+_file)
-                
+
     def _write_index_file(self, type):
         _info=self.media_info.get(type, None)
         if not _info:
@@ -682,7 +746,7 @@ class Phone(com_lg.LGNewIndexedMedia2,com_lgvx7000.Phone):
         # wp contains items that we still need to add, and weren't in the existing index
         assert len(wpi)==0
         print init.keys()
-        
+
         # now look through wallpapers and see if anything was assigned a particular
         # origin
         for w in wp.keys():
@@ -715,7 +779,15 @@ class Phone(com_lg.LGNewIndexedMedia2,com_lgvx7000.Phone):
                 if common.basename(item.filename) not in names and \
                    not self._is_rs_file(item.filename):
                     self.log(item.filename+" is being deleted")
-                    self.rmfile(item.filename)
+                    try:
+                        self.rmfile(item.filename)
+                    except (com_brew.BrewNoSuchDirectoryException,
+                            com_brew.BrewBadPathnameException,
+                            com_brew.BrewNoSuchFileException):
+                        pass
+                    except:
+                        if __debug__:
+                            raise
             # fixup the indices
             fixups=[k for k in init[type].keys() if k<lowestindex]
             fixups.sort()
@@ -746,7 +818,7 @@ class Phone(com_lg.LGNewIndexedMedia2,com_lgvx7000.Phone):
                 # check len(data) against fstat->length
                 data=entry['data']
                 if data is None:
-                    assert merge 
+                    assert merge
                     continue # we are doing an add and don't have data for this existing entry
                 elif not data:
                     self.log('Not writing file: '+filename)
@@ -777,7 +849,7 @@ class Profile(parentprofile):
 
     # the 8100 uses "W" for wait in the dialstring, it does not support "T"
     DIALSTRING_CHARS="[^0-9PW#*]"
-   
+
     MAX_RINGTONE_BASENAME_LENGTH=32
     RINGTONE_FILENAME_CHARS="ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789()_ .-"
 
@@ -815,7 +887,7 @@ class Profile(parentprofile):
     def GetTargetsForImageOrigin(self, origin):
         return self.imagetargets
 
- 
+
     def __init__(self):
         parentprofile.__init__(self)
 
@@ -857,7 +929,7 @@ class Profile(parentprofile):
             'storage': 0,
             },
         'calendar': {
-            'description': True, 'location': True, 'allday': True,
+            'description': True, 'location': False, 'allday': True,
             'start': True, 'end': True, 'priority': False,
             'alarm': True, 'vibrate': True,
             'repeat': True,
