@@ -5,7 +5,7 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: com_samsungscha650.py 3037 2006-04-03 00:30:28Z rogerb $
+### $Id: com_samsungscha650.py 3451 2006-07-08 04:44:02Z djpham $
 
 
 """Communicate with a Samsung SCH-A650"""
@@ -923,7 +923,7 @@ class PhoneBook:
                           'serial1': `pb_cnt`,
                           'serial2': `mem_index` }]
         # only one name
-        res['names']=[ {'full': unicode(e.name, errors='ignore') } ]
+        res['names']=[ {'full': e.name } ]
         if e.alias_num_index:
             res['names'][0]['nickname']=self.__numbers.get(e.alias_num_index, '')
 
