@@ -5,7 +5,7 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: com_sanyo3100.py 2655 2005-11-29 03:02:39Z sawecw $
+### $Id: com_sanyo3100.py 3636 2006-11-04 05:00:15Z sawecw $
 
 """Talk to the Sanyo SCP-3100 cell phone"""
 # standard modules
@@ -15,6 +15,7 @@ import sha
 
 # my modules
 import common
+import com_sanyo8300
 import p_brew
 import p_sanyo8300
 import p_sanyo3100
@@ -23,7 +24,6 @@ import com_phone
 import com_sanyo
 import com_sanyomedia
 import com_sanyonewer
-import com_sanyo8300
 import prototypes
 import bpcalendar
 
@@ -34,7 +34,7 @@ class Phone(com_sanyo8300.Phone):
     "Talk to the Sanyo PM3100 cell phone"
 
     desc="SCP3100"
-
+# WOrking directories 1,2,4
     FIRST_MEDIA_DIRECTORY=1
     LAST_MEDIA_DIRECTORY=2
 
@@ -45,17 +45,18 @@ class Phone(com_sanyo8300.Phone):
     protocolclass=p_sanyo3100
     serialsname='scp3100'
 
-    builtinringtones=( 'None', 'Vibrate', 'Ringer & Voice', '', '', '', '', '', '', 
+    builtinringtones=( 'None', 'Vibrate', '', '', '', '', '', '', '', 
                        'Tone 1', 'Tone 2', 'Tone 3', 'Tone 4', 'Tone 5',
-                       'Tone 6', 'Tone 7', 'Tone 8', '', '', '', '', '',
-                       '', '', '', '', '', '', '',
-                       'Tschaik.Swanlake', 'Satie Gymnop.#1',
-                       'Hungarian Dance', 'Beethoven Sym.5', 'Greensleeves',
-                       'Foster Ky. Home', 'The Moment', 'Asian Jingle',
-                       'Disco')
+                       'Tone 6', 'Tone 7', 'Tone 8',
+                       '', '', '', '', '',
+                       '', '', '',
+                       '', '', '', '',
+                       'Hungarian Dance No.5', 'Asian Jingle',
+                       'Ska Big Band', 'Habanera', 'Clair de Lune',
+                       'Nocturne', 'Techno Beat', 'Jazz Melody','','','','','','','','','','','','','','','','','','','Ringer & Voice')
 
-    calendar_defaultringtone=0
-    calendar_defaultcaringtone=0
+    calendar_defaultringtone=4
+    calendar_defaultcaringtone=4
 
     def __init__(self, logtarget, commport):
         com_sanyo8300.Phone.__init__(self, logtarget, commport)
@@ -70,11 +71,21 @@ class Profile(parentprofile):
     phone_manufacturer='SANYO'
     phone_model='SCP-3100/US'
 
-    WALLPAPER_WIDTH=176
-    WALLPAPER_HEIGHT=220
+    _supportedsyncs=(
+        ('phonebook', 'read', None),  # all phonebook reading
+        ('calendar', 'read', None),   # all calendar reading
+        ('phonebook', 'write', 'OVERWRITE'),  # only overwriting phonebook
+        ('calendar', 'write', 'OVERWRITE'),   # only overwriting calendar
+        ('wallpaper', 'read', None),  # all wallpaper reading
+        ('ringtone', 'read', None),   # all ringtone reading
+        ('call_history', 'read', None),# all call history list reading
+        ('sms', 'read', None), # Read sms messages
+        ('todo', 'read', None), # Read todos
+    )
 
     # which usb ids correspond to us
     usbids=( ( 0x0474, 0x071F, 1),)  # VID=Sanyo,
+    deviceclasses=("serial",)
     
     def __init__(self):
         parentprofile.__init__(self)
