@@ -5,7 +5,7 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: sms_tab.py 3298 2006-05-28 03:10:52Z skyjunky $
+### $Id: sms_tab.py 3647 2006-11-08 03:39:16Z djpham $
 
 """
 Code to handle the SMS Tab of the BitPim main display.
@@ -394,6 +394,11 @@ class SMSList(wx.Panel, widgets.BitPimWidget):
         self.SetAutoLayout(True)
         vbs.Fit(self)
 
+    def CanCopy(self):
+        return self._item_text.CanCopy()
+    def OnCopy(self, _):
+        self._item_text.Copy()
+
     def OnSelected(self, node):
         for stat in self._stats.msg_type_list:
             if self._stats.sms_tree_nodes[stat]==node:
