@@ -5,7 +5,7 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: vcal_calendar.py 3292 2006-05-26 03:58:56Z djpham $
+### $Id: vcal_calendar.py 3496 2006-07-25 03:18:28Z djpham $
 
 "Deals with vcard calendar import stuff"
 
@@ -25,6 +25,12 @@ import vcard
 
 module_debug=False
 
+#-------------------------------------------------------------------------------
+class ImportDataSource(common_calendar.ImportDataSource):
+    # how to define, and retrieve calendar import data source
+    message_str="Pick a vCal Calendar File"
+    wildcard='*.vcs;*.ics'
+
 #-------------------------------------------------------------------------------
 class vCalendarFile(object):
     def __init__(self, file_name=None):
